==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/tenodeconnectivitymatrixabs/connectivitymatrix/DefaultFrom.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.tenodeconnectivitymatrixabs.connectivitymatrix;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of from.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultFrom extends InnerModelObject implements From {
    protected Object tpRef;
    protected Object nodeRef;
    protected Object networkRef;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public Object tpRef() {
        return tpRef;
    }

    @Override
    public Object nodeRef() {
        return nodeRef;
    }

    @Override
    public Object networkRef() {
        return networkRef;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void tpRef(Object tpRef) {
        valueLeafFlags.set(LeafIdentifier.TPREF.getLeafIndex());
        this.tpRef = tpRef;
    }

    @Override
    public void nodeRef(Object nodeRef) {
        valueLeafFlags.set(LeafIdentifier.NODEREF.getLeafIndex());
        this.nodeRef = nodeRef;
    }

    @Override
    public void networkRef(Object networkRef) {
        valueLeafFlags.set(LeafIdentifier.NETWORKREF.getLeafIndex());
        this.networkRef = networkRef;
    }

    @Override
    public int hashCode() {
        return Objects.hash(tpRef, nodeRef, networkRef, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultFrom) {
            DefaultFrom other = (DefaultFrom) obj;
            return
                Objects.equals(tpRef, other.tpRef) &&
                Objects.equals(nodeRef, other.nodeRef) &&
                Objects.equals(networkRef, other.networkRef) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("tpRef=" + tpRef)
            .add("nodeRef=" + nodeRef)
            .add("networkRef=" + networkRef)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultFrom.
     */
    public DefaultFrom() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/tenodeconnectivitymatrixabs/connectivitymatrix/DefaultFrom.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.tenodeconnectivitymatrixabs.connectivitymatrix;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of from.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultFrom extends InnerModelObject implements From {
    protected Object tpRef;
    protected Object nodeRef;
    protected Object networkRef;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public Object tpRef() {
        return tpRef;
    }

    @Override
    public Object nodeRef() {
        return nodeRef;
    }

    @Override
    public Object networkRef() {
        return networkRef;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void tpRef(Object tpRef) {
        valueLeafFlags.set(LeafIdentifier.TPREF.getLeafIndex());
        this.tpRef = tpRef;
    }

    @Override
    public void nodeRef(Object nodeRef) {
        valueLeafFlags.set(LeafIdentifier.NODEREF.getLeafIndex());
        this.nodeRef = nodeRef;
    }

    @Override
    public void networkRef(Object networkRef) {
        valueLeafFlags.set(LeafIdentifier.NETWORKREF.getLeafIndex());
        this.networkRef = networkRef;
    }

    @Override
    public int hashCode() {
        return Objects.hash(tpRef, nodeRef, networkRef, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultFrom) {
            DefaultFrom other = (DefaultFrom) obj;
            return
                Objects.deepEquals(tpRef, other.tpRef) &&
                Objects.deepEquals(nodeRef, other.nodeRef) &&
                Objects.deepEquals(networkRef, other.networkRef) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("tpRef=" + tpRef)
            .add("nodeRef=" + nodeRef)
            .add("networkRef=" + networkRef)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultFrom.
     */
    public DefaultFrom() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
